#!/bin/bash
#
# The script starts LSF jobs for the PETSc application.
#
# Copyright (c) 2013, ZIH, TU Dresden, Federal Republic of Germany.
# For details, see the files COPYING and LICENSE in the base directory
# of the package.

#------------------------------------------------------------------------------#
# Set parameters.
nameProgram="HeatEqnFDM2D_Petsc"
exeDir="HeatEqnFDM2D/petsc"
resDir="results/petsc"
softwareVersion="petsc_3_4_3_complex"
system="ZIH_ATLAS"

#------------------------------------------------------------------------------#
nNodesX="4096";
nNodesY="4096";
nTimesteps="20";
str_endTime="4E-7" #TODO: Must be set by hand.
nTimestepsTotal="50000000";
memoryPerCore="1024";
nMeasurements=7;
declare -i local nProcesses=1;
declare -i local nThreads=1;

#------------------------------------------------------------------------------#
#------------------------------------------------------------------------------#
timestamp=$(date +%Y%m%d%H%M);

for ii in `seq 1 $nMeasurements`; do
    str_nProcesses=$(printf "%.5d" $nProcesses);
    str_nNodesX=$(printf "%.4d" $nNodesX);
    str_nNodesY=$(printf "%.4d" $nNodesY);
    str_nTimesteps=$(printf "%.6d" $nTimesteps);
    basefile="${resDir}/${nameProgram}"
    basefile="$basefile-${system}"
    basefile="$basefile-${softwareVersion}"
    basefile="$basefile-np${str_nProcesses}"
    basefile="$basefile-grid${str_nNodesX}x${str_nNodesY}"
    basefile="$basefile-nTs${str_nTimesteps}"
    basefile="$basefile-tEnd${str_endTime}"
    basefile="$basefile-${timestamp}"
    outputfile="$basefile.out"
    errorfile="$basefile.err"

    export OMP_NUM_THREADS=$nThreads
#     bsub \
#      -n ${nProcesses} \
#      -o ${outputfile} \
#      -e ${errorfile} \
#      -J ${nameProgram} \
#      -M ${memoryPerCore} \
     mpirun -np ${nProcesses} ./${exeDir}/${nameProgram} \
            -m ${nNodesX} -n ${nNodesY} \
            -t ${nTimesteps} -tt ${nTimestepsTotal} \
                    > ${outputfile} \
                    2> ${errorfile}

    nProcesses=$((nProcesses*2));
done
